bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 37. Aventiure
___________________________________________________ #### Aventivr wie der marchgrave Rvodeger erslagen wart
| ### z heten die ellende wider morgen gvot getan ### wine der Gotlinde chom ze hove gegan ### do sach er beidenthalben div grozlichen ser ### daz weinte innechliche der vil getriwe Rvedeger
###### 2073 | ### So we mich sprach der reke daz ich den lip gewan ### daz disen grozen iamer chan niemen vnderstan [84b] ### swie gern ichz friden wolde der kvnich tvt ez niht ### wand er der sinen læide ie mer vn– mer gesiht
###### 2074 | ### Do sant an Dietriche der gvote Rvedeger ### ob siz noch chvnden wenden an dem kvnige her ### do enbot im der von Berne wer moht ez vnderstan ### ez enwil der kvnich Ezel nieman schaiden lan
###### 2075 | ### Do sach ein kvene recke Rvedergern stan ### mit wæinvnden ovgen vnt hetez vil getan ### der sprach zer chvniginne nv seht ir wie er stat ### der doch gewalt den mæisten hie bi Ezeln hat
###### 2076 | ### vnt dem ez allez dienet livt vnd lant ### wie ist so vil der bvrge an Rvedeger gewant ### der er von dem kvnige vil manige haben mach ### er slvoch in disem stvrme noch nie loblichen slach
###### 2077 | ### Mich dvncket er rvoche wie ez hier vmbe gat ### sit daz er den vollen nach sinen willen hat ### man giht im er si chvener danne ieman mvge sin ### daz ist in disen sorgen worden loslichen schin
###### 2078 | ### Mit trvrigem mvote der vil getriwe man ### den er daz reden horte der helt der blichte in an ### er gedaht dv solt ez arnen dv gihst ich si verzagt ### dv hast div dinen mere ze hove ze lvte gesagt
###### 2079 | ### Die fveest begvnder twingen do lief er in an ### vnd slvoch so chreftichliche den Hivonischen man ### daz er im vor den fvezen lack vil schiere tot ### do waz aver gemeret des kvnich Ezeln not
###### 2080 | ### Hin dv zage mere sprach do Rvedeger ### ich han doch genvoge leit vn– herzen ser ### daz ich hie niht envihte zwev wizzet dv mir daz ### ia wer ich den gesten von grozen schvlden gehaz
###### 2081 | ### vnd allez daz ich mohte daz het ich getan ### niwan daz ich die reken her gefveret han ### ia was ich ir gelæite in mines herren lant ### des ensol mit in niht striten min vil ellendes hant
###### 2082 | ### Do sprach zem marcraven Ezel der kvnich her ### wie habt ir vns geholfen vil edel Rvedeger ### wan wir so vil der væigen hie ze lande han ### wir bedvrfen ir niht mere ir hapt vil vbel getan
###### 2083 | ### Do sprach der ritter edele ia beswart er mir den mvot ### vn– hat mir geitewizet ere vnd vovt ### des ich von dinen handen so vil han genomen ### daz ist dem lvgenere ein tæil ze vnstaten komen
###### 2084 | ### Do kom div kvniginne vn– het ez ovch gesehen ### daz von des heldes zorne dem Hevne waz geschehen ### si klagt ez vngefvoge ir ovgen wurden naz ### si sprach zvo Rvedegere wie habe wir verdienet daz
###### 2085 | ### daz ir mir vnt dem kvnige meret vnser leit ### nv habt ir edel Rvedeger vns allez her geseit ### ir woldet dvrch vns wagen die ere vn– daz leben ### ich hort iv vil der reken den bris vil grozlichen geben [85a]
###### 2086 | ### Ich mane iv der genaden vn– ir mir hant gesworn ### do ir mir zvo Ezeln rietet riter vz erkorn ### daz ir mir woldet dienen vntz an vnser æines tot ### der wart mir arm wibe nie so grozlichen not
###### 2087 | ### Daz ist ane lavgen ich swor iv edel wip ### daz ich dvrch ivch wagte die ere vn– ovch den lip ### daz ich die sele flieze des han ich niht gesworn ### zvo dirre hochgezite batich die fvrsten wol geborn
###### 2088 | ### Si sprach gedenke Rvedeger der <grozen> triwe din ### der stete vnd ovch der eide daz dv den schaden min ### immer woldest rechen vn– elliv minev læit ### do sprach der margrave ich han iv e selten iht verseit
###### 2089 | ### Ezel der riche flegen ovch began ### si bvten sich ze fvoze bæide fvr den man ### den edeln margraven vmmvotes man do sach ### der vil getriwe reke harte iemerkliche do sprach
###### 2090 | ### Owe mich gotes armen daz ich ditz gelebt han ### aller miner eren der mvoz ich ab stan ### triwen vnd zvhte der got an mir gebot ### owe got von himel daz mihs niht wendet der tot
###### 2091 | ### Swelhs ich nv laze vn– daz ander began ### so han ich boeslich vn– vil vbel getan ### laz aber ich si bæide mich schendet elliv diet ### nv rvoche mich bewisen der mir ze lebene geriet
###### 2092 | ### Do baten si genote der kvnich vn– ovch sin wip ### des mvosen sider reken fliezen den lip ### von Rvedegers hende da ovch der helt erstarp ### ir mvgt daz hie wol hoern daz er vil iæmerchlichen warb
###### 2093 | ### Er weste schaden gewinnen vn– vngefvogiv læit ### er hete dem kvnige vil gerne verseit ### vnd ovch der kvniginne vil sere vorht er daz ### ob er ir æinen slvege div werlt trvege im darvmbe haz
###### 2094 | ### Do sprach zvo dem kvnige der vil kvene man ### her kvnich nv nemt hin widere swaz ich von iv han ### daz lant mit den bvrgen der sol mich <niht> bestan ### ich wil vf minen fvezen in daz ellende gan
###### 2095 | ### Do sprach der chvnik Ezel wer hvlfe danne mir ### daz lant zvo den lveten daz gibich allez dir ### daz dv mich rechest Rvedeger an den vinden min ### dv solt ein kvnich gewaltich bineben Ezeln sin
###### 2096 | ### Do sprach aber Rvedeger wie sol ichs ane van ### hæim ze minem hvse ich si geladen han ### trincken vn– spise ich in gvetlichen bot ### vnt gab im mine gabe wie sol ich raten in den tot
###### 2097 | ### Div livte wenent lihte daz ich si verzagt ### deheinen minen dienst han ich in versagt ### den vil edeln fvrsten vnt ovch ir man ### ovch riwet mich div frivntschaft <die> ich mit in geworben han
###### 2098 | ### Giselher dem degene gab ich die tohter min [85b] ### si kvnde in dirre werlde niht baz verwendet sin ### vf zvht vn– ovch vf ere vf triwe vn– vf gvot ### ich gesach nie kvnich ivngen so rehte tvgenlichen gemvot
###### 2099 | ### Do sprach aber Kriemh' vil edel Rvedeger ### nv la dich erbarmen vnser beider ser ### min vn– ovch des kvniges gedenche wol daran ### daz nie wirt dehæiner so læide geste mer gewan
###### 2100 | ### Do sprach der margrave wider daz edel wip ### ez mvoz hivte gelten der Rveders lip ### swaz ir vn– ovch min herre mir liebes hapt getan ### darvmbe mvoz ich sterben daz chan niht langer bestan
###### 2101 | ### Ich weiz wol daz moch hivte min bvrge vn– och min lane ### iv mvezen leidich werden von ir etesliches hant ### ich bevilheiv vf genade min wip vn– miniv kint ### vn– ovch die vil ellenden die ze Bechelaren sint
###### 2102 | ### Nv lon dir got Rvedeger sprach der kvnich do ### er vn– div kvniginne si wurden bæidiv vro ### vns svln dine lvte vil wol enpholhen wesen ### ovch trowe ich minem heile daz dv maht selbe wol genesen
###### 2103 | ### Do liez er an die wage <sele> vnd lip ### do begvnde wæinen daz Ezeln wip ### er sprach ich mvoz iv læisten als ich gelopt han ### owe der minen frivnde die ich vngerne hie bestan
###### 2104 | ### Man sach in von <dem> kvnige vil trovrichlichen gan ### do vant er sine reken vil nahen bi im stan ### er sprach ir svlt ivch waffen alle mine man ### die kvenen Bvrgonden die mvoz ich leider bestan
###### 2105 | ### Si hiezen balde springen da man ir gewaffen vant ### ez der helm were od des schildes rant ### von ir ingesinde wart ez in dar getragen ### seid horten leidiv mere die stolzen ellende sagen
###### 2106 | ### Gewaffent wart der Rvedeger mit fvmf hvndert man ### dar vber zwelf reken sach man mit im gan ### die wolten pris erwerben in des stvrmes not ### si enwessen niht der mere daz in so nahent der tot
###### 2107 | ### Do sach man Rvedegere vnder helme gan ### ez trvogen swert div scharpfen des margraven man ### dar zvo vor ir handen die liehte schilde bræit ### daz sach der videlere ez waz im grozlichen læit
###### 2108 | ### Do sach der ivnge Giselher sinen sweher gen ### mit vf gebvnden helm wie moht man do versten ### waz er da mit mæinte niwan allez gvot ### des wart der kvnich edel so rehte froelich gemvot
###### 2109 | ### Nv wol mich solher frivnde sprach Giselher der degen ### die wir han gewunnen nv vf disen wegen ### wir svln vil wol geniezen mines wibes hie ### mir ist liep vf min triwe daz ie der heirat ergie
###### 2110 | ### Ich wæiz wes ir ivch troestet sprach der spileman ### wa saht ir ie dvrch svone so manigen helt gan ### mit vf gebvnden helmen die trvogen swert in der hant [86a] ### an vns wil dienen Rvedeger sein bvrge vn– siniv lant
###### 2111 | ### E daz der videlere die rede do vol sprach ### Rvedegern den edeln man vor dem hvse sach ### sinen schilt den gvoten den satz er fvr den fvoz ### do mvos er sinen frivnden versagen dienst vn– grvoz
###### 2112 | ### Der edel margrave rief do in den sal ### ir chvone Nybelvnge nv wert ivch vber al ### ir soldet min geniezen nv engeltet ir min ### e do war wir frivnde der triwe wil ich ledich sein
###### 2113 | ### Do erschrahten dirre mere die nothaften man ### wan ir deheiner frovde nie da von gewan ### daz mit im wolde striten dem si da waren holt ### si heten von veinden vil michel arbeit gedolt
###### 2114 | ### Nv ne welle got von himel sprach Gvnther der degen ### daz ir ivch genaden svlt an vns bewegen ### vn– der vil grozen triwe der wir doch heten mvot ### ich wil iv des getrovwen daz ir ez nimmer getvot
###### 2115 | ### Iane mag ichz niht gelazen sprach der kvene man ### ich mvoz mit iv striten wan ichs gelobt han ### nv wert ivch chvene helde so lieb iv si der lip ### mich woltez niht erlazen des chvnich Ezeln wip
###### 2116 | ### Ir widersagt vns nv ze spate sprach der kvnich her ### nv mvoz iv got vergelten vil edel Rvedeger ### triwe vn– minne die ir vns hapt getan ### ob ir ez an dem ende woldet gvotlicher lan
###### 2117 | ### Wir soltenz immer dienen daz ir vns hapt gegeben ### ich vnt mine mage ob ir vns liezet leben ### der herlichen gabe do ir vns brahtet her ### in Ezeln lant zen Hevnen des gedenchet vil edel Rvedeger
###### 2118 | ### Wie wol ich iv des gvnde sprach Rvedeger der degen ### daz ich iv mine gabe mit vollen solde geben ### also willechliche als ich des hete wan ### sone wurde mir darvmbe nimmer schelten getan
###### 2119 | ### Erwindet edel Rvedeger sprach do Gernot ### wan ez wirt deheiner gesten nie erbot ### so rehte minnechlichen als ir vns hapt getan ### des svlt ir wol geniezen ob wir bi leben bestan
###### 2120 | ### Daz wolde got sprach Rvedeger vil edel Gernot ### daz ir ze Rine wert vnd ich were tot ### mit etlichen eren seid ich iv sol bestan ### ez wart an ellenden von frivnden noh nie wirs getan
###### 2121 | ### Nv lone iv got her Rvedeger sprach do Gernot ### der vil richen gabe mich riwet iwer tot ### sol an iv verderben so tvgentlicher mvot ### hie trag ich iwer waffen daz ir mir gabt helt gvot
###### 2122 | ### Daz ist mir nie geswichen in aller dirre not ### vnder sinen eken lit manich riter tot ### ez ist lvter vnd stete herlich vnd gvot ### ich wene so riche gabe ein reke nimmer mer getvot
###### 2123 | ### Vnde welt ir niht erwinden ir welt zvo vns gan [86b] ### slaht ir mir iht der frivnde die ich hinne han ### mit iwer selbes swerte nim ich iv den lip ### so riwet ir mich Rvedeger vn– iwer herlichez wip
###### 2124 | ### Daz wolde got her Gernot vnd meht ez ergan ### daz aller iwer wille were hie getan ### vnd daz genesen were iwer frivnde lip ### ia sol iv wol getruowen beidiv mit tohter vnde min wip
###### 2125 | ### Do sprach von Bvrgonden der schoenen voten kint ### wie tvot ir so her Rvedeger di mit mir komen sint ### die sint iv alle wege ir griffet vbel zvo ### die iwer schoene tohter welt ir verwitwen ze frvo
###### 2126 | ### Swenne ir vn– iwer reken mit strite mich bestat ### wie reht vnfrivntliche ir daz schinen lat ### daz ich iv wol <getrvwe> fvr alle ander man ### da von ich ze wibe iwer tohter mir gewan
###### 2127 | ### Gedenchet iwer triwen vil edel kvnich her ### gesende iv got von hinne so sprach Rvedeger ### lat die ivnchvrowen niht engelten min ### dvrch iwer selber tvgende so rvochet ir genedich sin
###### 2128 | ### Daz tet ich billich sprach Giselher daz kint ### die hoehen mine mage di noch hier inne sint ### svln die von iv sterben so mvoz gescheiden sin ### div vil stete frivntschaft zvo dir vn– der tohter din
###### 2129 | ### Nv mvoz vns got genaden sprach der kvene man ### do hvoben si die schilde also si wolden dan ### striten zvo den gesten in Kriemhilt sal ### do rief vil lvte Hagene von der stiege hin zetal
###### 2130 | ### Belibet ein wile vil edel Rvedeger ### also sprach do Hagen wir wolden reden mer ### ich vn– mine herren als vns des twinget not ### waz mack gehelfen Ezeln vnser ellender tot
###### 2131 | ### Ich sten in grozen sorgen sprach aber Hagne ### den schilt den mir vrovwe Gotlint gab ze tragene ### den habent mir die Hevnen zerhovwen von der hant ### ich fvert in frivntliche in daz Ezeln lant
###### 2132 | ### Daz des got von himel rvochen wolde ### daz ich schilt so gvoten noch tragen solde ### so den dv hast vor hende vil edel Rvedeger ### so bedorfte ich in dem stvrme deheiner <halsperge> mer
###### 2133 | ### Vil gerne wer ich dir gvot mit minem schilde ### getoerst ich drin gebieten vor Kriemhilde ### doch nim dv in hin Hagen vn– trag in an der hende ### hey soldestv in fvern in der Bvrgonden lant
###### 2134 | ### Do er im so willechlichen den schilt ze geben bot ### do wart genvoger ovgen von <heizen> trehen rot ### ez waz div leste gabe die sider immer mer ### bot deheinem degene von Bechlarn Rvedeger
###### 2135 | ### Swie grimme Hagen were vnt swie zornich gemvot ### ia erbarmet im div gabe die der helt gvot ### bi sinem lesten ziten so nahen het getan [87a] ### vil manich riter edel mit im trvren began
###### 2136 | ### Nv lone in got von himel vil edel Rvedeger ### ez wirt iwer geliche deheiner nimmer mer ### der ellenden reken so herlichen gebe ### so sol daz got gebieten daz iwer tvgende immer lebe
###### 2137 | ### So we mich dirre mere so sprach aber Hagene ### wir heten ander swere so vil ze tragene ### svl wir mit frivnden striten daz si got geklæit ### do sprach der marchgrave daz ist mir innechliche læit
###### 2138 | ### Nv lon ich iv der gabe vil edel Rvedeger ### swie halt gæin iv gebaren dise reken her ### daz nimmer ivch gerveret mit strite hie min hant ### ob ir si alle slveget die von Bvrgonden lant
###### 2139 | ### Des neig im mit zvhten der gvote Rvedeger ### si wæinten allenthalben daz disiv herzen ser ### niemen scheiden chvnde daz waz ein michel not ### vater aller tvgende lag an Rvedegere tot
###### 2140 | ### Do sprach von dem hvse Volker der spileman ### sit min geselle Hagen den vride hat getan ### den svlt ir also stete haben von miner hant ### daz hapt ir wol verdienet do wir komen in daz lant
###### 2141 | ### Vil edel marchgrave ir svlt min bote sin ### dise rote bovge gab mir div margravin ### daz <ich> si tragen solde hiehgezit ### die mvgt ir selbe schowen daz ir dez min gezivge sit
###### 2142 | ### Daz wolde got der riche sprach do Rvedeger ### daz iv div margravinne noch solte geben mer ### div mer sag ich gerne der trivtinne min ### gesihe ich si gesvnder des svlt ir ane zwifel sin
###### 2143 | ### Als er im daz gelobte den schilt hvop Rvedeger ### des mvotes er ertobte do en bæit er da niht mer ### do lief er zvo den gesten einem degen gelich ### manigen slach vil swinden slvoch der margrave rich
###### 2144 | ### Die zwene stvonden hoher Volker vn– Hagene ### wan ez itn e gelobten die zwene degene ### noch vant er als chvenen bi den tvren stan ### daz Rvedeger des strites mit grozen sorgen began
###### 2145 | ### Dvrch mortrechen willen so liezen si dar in ### Gvnther vn– Gernot si heten helde sin ### do stvond hoher Giselher zwar ez waz im læit ### er versach sich noch des lebens da von er Rvedegern mæit
###### 2146 | ### Do sprvngen zvo den veinden des margraven man ### man sach si nach ir herren vil tvgentlichen gan ### div snidvnde wafen si trvogen an der hant ### des brast da vil der helm vn– manich herlicher rant
###### 2147 | ### Do slvogen die vil mveden vil manigen swinden slach ### den von Bechelaren der eben vnt tiefe wack ### dvrch die vesten ringe vast vntz vf daz werch ### si taten in dem stvrme div vil herlichen werch
###### 2148 | ### Daz edel ingesinde waz nv chomen gar dar in [87b] ### Volker vn– Hagen die sprvngen balde da hin ### si gaben fride nieman wan dem æinem man ### von ir bæider hende daz blvot nider dvrch helme ran
###### 2149 | ### Wie rehte gremliche vil swerte drinne erklanch ### vil der schiltspange zvo den slegen spranch ### der ræis vz ir schilt stæine nider in daz blvot ### si vahten also grimme daz manz nimmer mer getvot
###### 2150 | ### Der vogt von Bechelern gie wider vnde dan ### also der mit ellen in stvrme werben kan ### dem tet des tages Rvedeger harte wol gelich ### daz er ein rekhe were vil chvene vn– lobelich
###### 2151 | ### Hie stvonden dise reken Gvnther vnd Gernot ### si slvogen in dem strite vil manigen helt tot ### Giselher vn– Dancwart die zwene ez ringe wach ### des frvmten si vil manigen hintz vf den ivngisten tack
###### 2152 | ### Vil wol zaigte Rvedeger daz er waz starke genvoch ### chvonen vnde wol gewafent hey was er helde slvoch ### daz sach ein Bvrgonde zorns was im not ### da von begvnde nahen des edeln Rvedegers tot
###### 2153 | ### Gernot der starcke den helt den rief er an ### er sprach zem margraven ir welt mir miner man ### niht genezen lazen vil edel Rvedeger ### daz mvet mich ane maze ich chans niht an gesehen mer
###### 2154 | ### Nv mag iv iwer gabe wol ze schaden chomen ### sit ir mir miner frivnde hapt so vil benomen ### nv wendet ivch her vmbe vil edel chvene man ### iwer gabe wirt verdienet so ich iz aller hoehste chan
###### 2155 | ### E daz der margrave zvo im vol chome dar ### des mvosen liehte ringe werden missevar ### do sprvngen zvo ein ander die eren gernde man ### ir ietweder schermin fvr starche wunden began
###### 2156 | ### Ir swert so scharpsch waren sine chvnde niht gewegen ### do slvoch Gernoten Rveger der degen ### dvrch flinsherten helm daz nider floz daz blvot ### daz vergalt im sere der riter chven vnd gvot
###### 2157 | ### Die Rvedegers gabe an hende er hoeher wack ### swie wunt er wer zem tode er slvog im einen slach ### dvrch den schilt vil gvoten vntz vf div helmgespan ### da von mvos ersterben do der Gotlinden man
###### 2158 | ### Ia wart nie wirs gelonet so richer gabe mer ### do vielen beide erslagne Gernot vnd Rvedeger ### gelich in dem stvrme von ir beider hant ### alrest erzvrnde Hagne do der den grozen schaden bevant
###### 2159 | ### Do sprach der von Tronge ez ist vns vbel chomen ### wir haben an in bæiden so grozen schaden genomen ### den wir nimmer vberwinden ir livet vn– ovch ir lant ### die Rvedegeres helde sint vnser ellenden phant
###### 2160 | ### Owe mich mines brvoder der tot ist hie gefrvmt ### waz mir der leiden mere ze allen ziten chvnt ### ovch mvoz mich immer riwen der edel Rvedeger [88a] ### der schade ist beidenthalben vn– div grozlichen ser
###### 2161 | ### Do der ivnge Giselher sach sinen brvoder tot ### die do dar inne waren die mvosen liden not ### der tot der svochte sere da sin gesinde was ### der von Bechelarn do langer einer niht genas
###### 2162 | ### Gvnther vn– Giselher vnd ovch Hagene ### Dancwart vn– Volker die gvoten degene ### die giengen da si fvnden ligen die zwene man ### do wart da von den helden mit iamer wainen began
###### 2163 | ### Der tot vns sere rovbet sprach Giselher daz chint ### nv lazet iwer wainen vnt ge wir an den wint ### daz vns die ringe erchvolen vns stritmveden man ### ia wen vns got hie langer niht ze lebene gan
###### 2164 | ### Den sitzen disen læinen sach man manigen degen ### si waren aber mvezich da warn tot gelegen ### die Rvedegers helde zergangen waz der doz ### so lange wert div stille daz sin Ezeln verdroz
###### 2165 | ### Owe dirre <dienste> sprach des chvniges wip ### dine sint niht so stete daz vnser veinde lip ### mvege des engelten von Rvedegeres hant ### er wil si wider bringen in der Bvrgonde lant
###### 2166 | ### Waz hilfet chvnich Ezel daz wir getæilet han ### mit im swaz er wolde der helt hat missetan ### der vns da solde rechen der wil der svone pflegen ### des antwurt ir do Volker der vil zierliche degen
###### 2167 | ### Der rede enist so niht leider vil edels kvniges wip ### getoerst ich heizen liegen alsvs edeln lip ### so het ir tievelichen an Rvedeger gelogen ### er vnt die sine degene sint an der svone gar betrogen
###### 2168 | ### Er tet so willechliche daz im der kvnich gebot ### daz er vnt sin gesinde ist hie gelegen tot ### nv seht al vmbe Kriemhilt wem ir nv gebieten welt ### iv hat vntz an den ende gedienet Rvedeger der helt
###### 2169 | ### Welt ir daz niht gelovben man sol ivchs sehen lan ### dvrch ir herzen sere so ware dvo daz getan ### man trvoch den helt verhovwen da in der kvnich sach ### den Ezeln degenen so rehte leide nie geschach
###### 2170 | ### Do si den margraven toten sahen tragen ### enchvnde ein schriber gebriefen noh gesagen ### e manigen vngeberde von wiben vn– ovch von man ### div sich von herzen iamer alda zeigen began
###### 2171 | ### Der Ezeln iamer der wart also groz ### als eines lewen stimme der riche kvnich erdoz ### mit herzemleide woffe alsam tet ovch sin wip ### si chlagten vngefvoge des gvoten Rvedegers lip

<<< Übersicht <<< vorige Seite nächste Seite >>>